# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkwaf_openapi.endpoint import endpoint_data

class SetDomainRuleGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'waf-openapi', '2019-09-10', 'SetDomainRuleGroup','waf')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_WafVersion(self): # Long
		return self.get_query_params().get('WafVersion')

	def set_WafVersion(self, WafVersion):  # Long
		self.add_query_param('WafVersion', WafVersion)
	def get_WafAiStatus(self): # Integer
		return self.get_query_params().get('WafAiStatus')

	def set_WafAiStatus(self, WafAiStatus):  # Integer
		self.add_query_param('WafAiStatus', WafAiStatus)
	def get_RuleGroupId(self): # Long
		return self.get_query_params().get('RuleGroupId')

	def set_RuleGroupId(self, RuleGroupId):  # Long
		self.add_query_param('RuleGroupId', RuleGroupId)
	def get_ResourceGroupId(self): # String
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # String
		self.add_query_param('ResourceGroupId', ResourceGroupId)
	def get_Domains(self): # String
		return self.get_query_params().get('Domains')

	def set_Domains(self, Domains):  # String
		self.add_query_param('Domains', Domains)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
